@@ -1,15 +1,15 @@
 #' @name improvement
 #' @rdname improvement
 #'
-#' @title Improvement for BLC fitted models
+#' @title BLC: Improvement
 #'
 #' @description Calculates the improvement of each age, based on the resulting chains of the beta parameter from a fitted blc model.
 #'
 #' @usage
-#' improvement(obj, cred = 0.95)
+#' improvement(obj, prob = 0.95)
 #'
 #' @param obj A `BLC` object, result of a call to blc() function.
-#' @param cred A real number that represents the credibility level of the intervals.
+#' @param prob A real number that represents the credibility level of the intervals.
 #'
 #' @return A data.frame with the improvement values of each age, as well as their credible intervals.
 #'
@@ -19,15 +19,15 @@
 #' Y <- PT
 #'
 #' ## Fitting the model
-#' fit = blc(Y = Y, numit = 100, warmup = 20)
+#' fit = blc(Y = Y, M = 100, bn = 20)
 #'
 #' ## Improvement:
 #' improvement(fit)
-#' improvement(fit, cred = 0.9) #90% credible intervals
+#' improvement(fit, prob = 0.9) #90% credible intervals
 #'
 #'
 #' @export
-improvement <- function(obj, cred = 0.95) {
+improvement <- function(obj, prob = 0.95) {
 	objClass <- class(obj)
 	supportedClasses <- c("BLC", "ARBLC")
 
@@ -35,11 +35,11 @@ improvement <- function(obj, cred = 0.95) {
 		stop("Invalid object type")
 	}
 
-	lower <- (1-cred)/2
-	upper <- (1+cred)/2
+	lower <- (1-prob)/2
+	upper <- (1+prob)/2
 
-	improvement <- apply(obj$beta[ ,(obj$warmup+1):obj$numit], 1, function (x) mean(1 - exp(-x)))
-	improvement.int <- apply(obj$beta[ ,(obj$warmup+1):obj$numit], 1, function (x) quantile(1 - exp(-x),
+	improvement <- apply(obj$beta[ ,(obj$bn+1):obj$M], 1, function (x) mean(1 - exp(-x)))
+	improvement.int <- apply(obj$beta[ ,(obj$bn+1):obj$M], 1, function (x) quantile(1 - exp(-x),
 	                                                                                        probs = c(lower, upper)))
 
 	data.frame(improvement = improvement, lower.lim = improvement.int[1,], upper.lim = improvement.int[2,])
